@@ -43,7 +43,7 @@ Editor::Editor(QWidget *parent): BaseWidget(parent)
 	search_dialog=NULL;
 	// Title
 	setWindowTitle(tr("Editor"));
-	setWindowIcon(QIcon(QString(ICON_PATH) + "/xedit.png"));
+	setWindowIcon(QIcon(QString(ICON_PATH) +QDir::separator()+ "xedit.png"));
 
 	// Layout
 	QVBoxLayout *vLayout = new QVBoxLayout;
@@ -64,19 +64,23 @@ Editor::Editor(QWidget *parent): BaseWidget(parent)
 	//toolBar->show();
 
 	// Toolbar buttons
-	actionNew = toolBar->addAction(QIcon(QString(ICON_PATH) + "/filenew.png"), tr("New"));
+	actionNew = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "filenew.png"), tr("New"));
 	actionNew->setShortcut(tr("Ctrl+N"));
-	actionOpen = toolBar->addAction(QIcon(QString(ICON_PATH) + "/fileopen"), tr("Open"));
+	actionNew->setShortcutContext(Qt::WindowShortcut);
+	actionOpen = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "fileopen"), tr("Open"));
 	actionOpen->setShortcut(tr("Ctrl+O"));
-	actionSave = toolBar->addAction(QIcon(QString(ICON_PATH) + "/filesave"), tr("Save"));
+	actionOpen->setShortcutContext(Qt::WindowShortcut);
+	actionSave = toolBar->addAction(QIcon(QString(ICON_PATH)  +QDir::separator()+ "filesave"), tr("Save"));
 	actionSave->setShortcut(tr("Ctrl+S"));
-	actionSaveAs = toolBar->addAction(QIcon(QString(ICON_PATH) + "/filesaveas.png"), tr("Save as"));
-	actionClose = toolBar->addAction(QIcon(QString(ICON_PATH) + "/fileclose.png"), tr("Close tab"));
+	actionSave->setShortcutContext(Qt::WindowShortcut);
+	actionSaveAs = toolBar->addAction(QIcon(QString(ICON_PATH)  +QDir::separator()+ "filesaveas.png"), tr("Save as"));
+	actionClose = toolBar->addAction(QIcon(QString(ICON_PATH)  +QDir::separator()+ "fileclose.png"), tr("Close tab"));
 	toolBar->addSeparator();
 
-	actionRun = toolBar->addAction(QIcon(QString(ICON_PATH) + "/run.png"), tr("Run"));
+	actionRun = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "run.png"), tr("Run"));
 	actionRun->setShortcut(tr("F5"));
-	actionDebug = toolBar->addAction(QIcon(QString(ICON_PATH) + "/find.png"), tr("Debug"));
+	actionRun->setShortcutContext(Qt::WindowShortcut);
+	actionDebug = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "find.png"), tr("Debug"));
 	actionDebug->setToolTip(
 		"<html>"
 		"<b>Debug:</b>"
@@ -84,27 +88,42 @@ Editor::Editor(QWidget *parent): BaseWidget(parent)
 		"<p>Click over this button to start debugging or continue to next breakpoint.</p>"
 		"</html>"
 	);
-	actionStep = toolBar->addAction(QIcon(QString(ICON_PATH) + "/step.png"), tr("Detailed debugging"));
+	actionDebug->setShortcut(tr("F6"));
+	actionStep = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "step.png"), tr("Detailed debugging"));
+	actionStep->setShortcut(tr("Shift+F6"));
 	actionStep->setEnabled(false);
-	actionSendToOctave=toolBar->addAction(QIcon(QString(ICON_PATH) + "/konsole.png"), tr("Send to Octave") );
+	actionSendToOctave=toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "konsole.png"), tr("Send to Octave") );
 	actionSendToOctave->setShortcut(tr("F9"));
+	actionSendToOctave->setShortcutContext(Qt::WindowShortcut);
+	actionSendToOctave->setToolTip(
+		"<html>"
+		"<b>Send to Octave:</b>"
+		"<p>Sends selected text to Octave. If there is not selected text, the full text will be sent.</p>"
+		"</html>"
+	);
 	toolBar->addSeparator();
 
-	actionUndo = toolBar->addAction(QIcon(QString(ICON_PATH) + "/undo.png"), tr("Undo"));
-	actionUndo->setShortcut(tr("Ctrl+Z"));
-	actionRedo = toolBar->addAction(QIcon(QString(ICON_PATH) + "/redo.png"), tr("Redo"));
-	actionRedo->setShortcut(tr("Ctrl+Shift+Z"));
-	actionCut = toolBar->addAction(QIcon(QString(ICON_PATH) + "/editcut"), tr("Cut"));
-	actionCut->setShortcut(tr("Ctrl+X"));
-	actionCopy = toolBar->addAction(QIcon(QString(ICON_PATH) + "/editcopy"), tr("Copy"));
-	actionCopy->setShortcut(tr("Ctrl+C"));
-	actionPaste = toolBar->addAction(QIcon(QString(ICON_PATH) + "/editpaste"),  tr("Paste"));
-	actionPaste->setShortcut(tr("Ctrl+V"));
+	actionUndo = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "undo.png"), tr("Undo"));
+	//actionUndo->setShortcut(tr("Ctrl+Z"));
+	//actionUndo->setShortcutContext(Qt::WindowShortcut);
+	actionRedo = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "redo.png"), tr("Redo"));
+	//actionRedo->setShortcut(tr("Ctrl+Shift+Z"));
+	//actionRedo->setShortcutContext(Qt::WindowShortcut);
+	actionCut = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "editcut"), tr("Cut"));
+	//actionCut->setShortcut(tr("Ctrl+X"));
+	//actionCut->setShortcutContext(Qt::WindowShortcut);
+	actionCopy = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "editcopy"), tr("Copy"));
+	//actionCopy->setShortcut(tr("Ctrl+C"));
+	//actionCopy->setShortcutContext(Qt::WindowShortcut);
+	actionPaste = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "editpaste"),  tr("Paste"));
+	//actionPaste->setShortcut(tr("Ctrl+V"));
+	//actionPaste->setShortcutContext(Qt::WindowShortcut);
 
 	toolBar->addSeparator();
 
-	actionSearch = toolBar->addAction(QIcon(QString(ICON_PATH) + "/search.png"),  tr("Search and replace"));
+	actionSearch = toolBar->addAction(QIcon(QString(ICON_PATH) +QDir::separator()+ "search.png"),  tr("Search and replace"));
 	actionSearch->setShortcut(tr("Ctrl+F"));
+	actionSearch->setShortcutContext(Qt::WindowShortcut);
 
 	//Create menus
 
@@ -113,6 +132,9 @@ Editor::Editor(QWidget *parent): BaseWidget(parent)
 	menuFile->addAction(actionOpen);
 	menuFile->addAction(actionSave);
 	menuFile->addAction(actionSaveAs);
+	actionClone=menuFile->addAction(tr("Clone View"));
+	connect(actionClone, SIGNAL(triggered()),this, SLOT(clone_callback()));
+
 	menuFile->addSeparator();
 	actionPrint=menuFile->addAction(tr("Print"));
 	connect(actionPrint, SIGNAL(triggered()),this, SLOT(print_callback()));
@@ -124,12 +146,17 @@ Editor::Editor(QWidget *parent): BaseWidget(parent)
 	//connect(menuFile, SIGNAL(triggered(QAction*)),this, SLOT(toolbar_action(QAction*)));
 
 	menuEdit=menuBar()->addMenu(tr("Edit"));
+	/*
 	menuEdit->addAction(actionUndo);
 	menuEdit->addAction(actionRedo);
 	menuEdit->addAction(actionCut);
 	menuEdit->addAction(actionCopy);
 	menuEdit->addAction(actionPaste);
 	menuEdit->addAction(actionSearch);
+	*/
+	connect(menuEdit, SIGNAL(aboutToShow()), this, SLOT(show_edit_menu()));
+	
+	
 	//connect(menuEdit, SIGNAL(triggered(QAction*)),this, SLOT(toolbar_action(QAction*)));
 
 	menuRun=menuBar()->addMenu(tr("Run"));
@@ -138,6 +165,10 @@ Editor::Editor(QWidget *parent): BaseWidget(parent)
 	menuRun->addAction(actionDebug);
 	menuRun->addAction(actionStep);
 	//connect(menuRun, SIGNAL(triggered(QAction*)),this, SLOT(toolbar_action(QAction*)));
+	menuRun->addSeparator();
+	actionToggleBreakPoint=menuRun->addAction(tr("Toggle breakpoint"));
+	actionToggleBreakPoint->setShortcut(tr("F7"));
+	connect(actionToggleBreakPoint, SIGNAL(triggered()),this, SLOT(toggleBreakPoint_callback()));
 
 	menuTools=menuBar()->addMenu(tr("Tools"));
 	actionIndent=menuTools->addAction(tr("Indent"));
@@ -155,6 +186,7 @@ Editor::Editor(QWidget *parent): BaseWidget(parent)
 		actionSimpleRCS=menuTools->addAction("Revision control system (SimpleRCS)");
 		connect(actionSimpleRCS, SIGNAL(triggered()),this, SLOT(simple_rcs_callback()));
 	}
+	
 
 	menuConfig=menuBar()->addMenu(tr("Config"));
 
@@ -214,6 +246,14 @@ Editor::~Editor()
 	if(search_dialog!=NULL) delete search_dialog;
 }
 
+void Editor::show_edit_menu()
+{
+	menuEdit->clear();
+	if(currentNtv!=NULL)
+		menuEdit->addMenu(currentNtv->textEdit()->createStandardContextMenu());
+	menuEdit->addAction(actionSearch);
+}
+
 void Editor::saveProject()
 {
 	QStringList files;
@@ -222,6 +262,7 @@ void Editor::saveProject()
 		QString path=((NumberedTextView*)tabWidget->widget(i) )->path();
 		if(!path.isEmpty()) files.append( path );
 	}
+	files.removeDuplicates();
 	if(project_name.isEmpty()) Projects::saveListFiles(tr("Empty"), files);
 	else Projects::saveListFiles(project_name, files);
 }
@@ -261,13 +302,13 @@ void Editor::toolbar_action(QAction *action)
 
   if(action == actionNew){
     /** New **/
-    CodeEdit *codeEdit = new CodeEdit(NULL, QString(CONFIG_PATH) + "/octave.xml");
+    SimpleEditor *codeEdit = new SimpleEditor(NULL);
     connect(codeEdit, SIGNAL(dynamic_help_required(const QString &)), this, SLOT(emit_dynamic_help_required(const QString &)));
 
     NumberedTextView *ntv = new NumberedTextView(NULL, codeEdit);
     connect(ntv->textEdit(), SIGNAL(toggleBreakpoint(int)), this, SLOT(toggleBreakpoint(int)));
     //connect(ntv, SIGNAL(textModified()), this, SLOT(textModified()));
-    connect(codeEdit, SIGNAL(text_modified (bool)), this, SLOT(textModified(bool)));
+    connect(codeEdit->document(), SIGNAL(modificationChanged (bool)), this, SLOT(textModified(bool)));
 
     currentNtv = ntv;
 
@@ -278,12 +319,10 @@ void Editor::toolbar_action(QAction *action)
 	openFile();
   }else if(action == actionSave && !currentNtv->path().isEmpty()){
     /* Save */
-    try{
-      currentNtv->save();
+    if( currentNtv->save() )
       setTabText(tabWidget->currentIndex(), currentNtv->path().split("/").last());
-    }catch(...){
+    else
       QMessageBox::critical(NULL, tr("Error"), tr("Can not be saved"));
-    }
 
   }else if(action == actionSaveAs || (action == actionSave && currentNtv->path().isEmpty())){
     /** Save as **/
@@ -315,10 +354,12 @@ void Editor::toolbar_action(QAction *action)
     {
       path = saveDialog.selectedFiles().first();
 
-      try{
-	currentNtv->save(path);
-	setTabText(tabWidget->currentIndex(), path.split("/").last());
-      }catch(...){
+      if(currentNtv->save(path))
+      {
+	setTabText(tabWidget->currentIndex(), currentNtv->path().split("/").last());
+      }
+      else
+      {
 	QMessageBox::critical(NULL, tr("Error"), path + tr("can not be saved"));
       }
     }
@@ -332,7 +373,7 @@ void Editor::toolbar_action(QAction *action)
 
 	QFileInfo finfo(currentNtv->path());
 	octave_connection->command_enter(QString("cd '") + finfo.path() + "'");
-	octave_connection->command_enter(finfo.baseName());
+	octave_connection->command_enter(QString("source (\"") +  finfo.fileName() + "\")");
 
   }else if(action == actionDebug){
     /** Run */
@@ -388,7 +429,7 @@ void Editor::toolbar_action(QAction *action)
 
   }else if(action == actionUndo){
     // Undo
-    ((CodeEdit*)currentNtv->textEdit())->undo();
+    ((SimpleEditor*)currentNtv->textEdit())->undo();
   }else if(action == actionRedo){
     // Undo
     currentNtv->textEdit()->document()->redo();
@@ -411,7 +452,7 @@ void Editor::toolbar_action(QAction *action)
 	search_dialog->show();
   }else if(action == actionSendToOctave){
     QTextCursor cursor=currentNtv->textEdit()->textCursor();
-    if(cursor.hasSelection()) octave_connection->command_enter(cursor.selectedText());
+    if(cursor.hasSelection()) octave_connection->command_enter(cursor.selectedText().replace(QChar(0x2029), "\n"));
     else octave_connection->command_enter( currentNtv->textEdit()->document()->toPlainText() );
   }else if(action == actionStep){
     octave_connection->command_enter( "dbstep" );
@@ -557,7 +598,7 @@ void Editor::tabChanged(int index)
 	//if(currentNtv!=NULL)
 	//	disconnect(currentNtv->textEdit(), SIGNAL(toggleBreakpoint(int)), this, SLOT(toggleBreakpoint(int)));
 	currentNtv = (NumberedTextView*)tabWidget->widget(index);
-	setWindowTitle(tabWidget->tabText(index));
+	//setWindowTitle(tabWidget->tabText(index));
 	//connect(currentNtv->textEdit(), SIGNAL(toggleBreakpoint(int)), this, SLOT(toggleBreakpoint(int)));
 	ListModel *list=(ListModel*)list_files->model();
 	list_files->setCurrentIndex(list->position_index(index));
@@ -565,16 +606,26 @@ void Editor::tabChanged(int index)
 
 void Editor::textModified(bool ok)
 {
-	if( !ok || currentNtv==NULL ) return;
-	QPlainTextEdit *text=currentNtv->textEdit();
-	if(!text->document()->isModified()) return;
-	if(currentNtv->path().isEmpty())
+	for(int i=0;i<tabWidget->count(); i++)
 	{
-		setTabText(tabWidget->currentIndex(), tr("New")+"*");
-	}
-	else
-	{
-		setTabText(tabWidget->currentIndex(), currentNtv->path().split("/").last()+"*");
+		NumberedTextView *ntv=(NumberedTextView *)tabWidget->widget(i);
+		if( ntv==NULL ) continue;
+		QPlainTextEdit *text=ntv->textEdit();
+		
+		if(ntv->path().isEmpty())
+		{
+			if(!text->document()->isModified()) 
+				setTabText(i, tr("New"));
+			else
+				setTabText(i, tr("New")+"*");
+		}
+		else
+		{
+			if(!text->document()->isModified()) 
+				setTabText(i, ntv->path().split("/").last());
+			else
+				setTabText(i, ntv->path().split("/").last()+"*");
+		}
 	}
 }
 
@@ -650,6 +701,28 @@ void Editor::closeTabs(bool close_all_tabs)
 		disconnect(currentNtv->textEdit()->document(), SIGNAL(modificationChanged (bool)), this, SLOT(textModified(bool)));
 		NumberedTextView *ntv=currentNtv;
 		currentNtv=NULL;
+		//TODO: Check if another view (clone view) is using the same document object
+		printf("Padre %d ; textEdit %d\n", ntv->textEdit()->document()->parent(), ntv->textEdit() );
+		//if(ntv->textEdit()->document()->parent()==ntv->textEdit())
+		/*
+		{
+			for(int i=0;i<tabWidget->count();i++)
+			{
+				NumberedTextView *w=(NumberedTextView *)tabWidget->widget(i);
+				if(
+					w!=ntv 
+					&& 
+					ntv->textEdit()->document()==w->textEdit()->document()
+				)
+				{
+					printf("Padre %d ; textEdit %d\n", w->textEdit()->document()->parent(), w->textEdit() );
+					ntv->textEdit()->document()->setParent(w->textEdit());
+					w->textEdit()->setDocument(ntv->textEdit()->document());
+					break;
+				}
+			}
+		}
+		*/
 		delete ntv;
 
 		if(!close_all_tabs) break;
@@ -658,11 +731,11 @@ void Editor::closeTabs(bool close_all_tabs)
 	// Crear uno si no queda ninguno
 	if(tabWidget->count() == 0)
 	{
-		CodeEdit *codeEdit = new CodeEdit(NULL, QString(CONFIG_PATH) + "/octave.xml");
+		SimpleEditor *codeEdit = new SimpleEditor(NULL);
 		connect(codeEdit, SIGNAL(dynamic_help_required(const QString &)), this, SLOT(emit_dynamic_help_required(const QString &)));
 		NumberedTextView *ntv = new NumberedTextView(NULL, codeEdit);
 		connect(ntv->textEdit(), SIGNAL(toggleBreakpoint(int)), this, SLOT(toggleBreakpoint(int)));
-		connect(codeEdit, SIGNAL(text_modified (bool)), this, SLOT(textModified(bool)));
+		connect(codeEdit->document(), SIGNAL(modificationChanged (bool)), this, SLOT(textModified(bool)));
 		//connect(ntv->textEdit()->document(), SIGNAL(modificationChanged (bool)), this, SLOT(textModified(bool)));
 
 		tabWidget->addTab(ntv, tr("New"));
@@ -679,37 +752,53 @@ void Editor::closeTabs(bool close_all_tabs)
 
 /////////////////////////////////////////////////////////////
 
+void Editor::newEditorTab()
+{
+	SimpleEditor *codeEdit = new SimpleEditor(NULL);
+	connect(codeEdit, SIGNAL(dynamic_help_required(const QString &)), this, SLOT(emit_dynamic_help_required(const QString &)));
+	NumberedTextView *ntv = new NumberedTextView(NULL, codeEdit);
+	connect(ntv->textEdit(), SIGNAL(toggleBreakpoint(int)), this, SLOT(toggleBreakpoint(int)));
+	
+	connect(codeEdit->document(), SIGNAL(modificationChanged (bool)), this, SLOT(textModified(bool)));
+	
+	tabWidget->setCurrentIndex(tabWidget->addTab(ntv, tr("New")));
+	
+	currentNtv=ntv;
+	
+	updateFileList();
+}
+
+/////////////////////////////////////////////////////////////
+
 void Editor::loadFiles(const QStringList &files)
 {
 	QString path;
 	foreach(path, files)
 	{
 		if( path.isEmpty() ) continue;
-		try{
+		
+		try
+		{
 			// Si la pestaña activa no contiene ningún texto ni es un archivo,
 			// abrir en ella
-			if(currentNtv->path().isEmpty() && currentNtv->textEdit()->document()->isEmpty())
+			
+			if(!currentNtv->path().isEmpty() || !currentNtv->textEdit()->document()->isEmpty())
 			{
-				setTabText(tabWidget->currentIndex(), path.split("/").last());
+				newEditorTab();
 			}
-			else
-			{
-				CodeEdit *codeEdit = new CodeEdit(NULL, QString(CONFIG_PATH) + "/octave.xml");
-				connect(codeEdit, SIGNAL(dynamic_help_required(const QString &)), this, SLOT(emit_dynamic_help_required(const QString &)));
-				NumberedTextView *ntv = new NumberedTextView(NULL, codeEdit);
-				connect(ntv->textEdit(), SIGNAL(toggleBreakpoint(int)), this, SLOT(toggleBreakpoint(int)));
-
-				tabWidget->setCurrentIndex(tabWidget->addTab(ntv, path.split("/").last()));
-				updateFileList();
-			}
-			CodeEdit *codeEdit=(CodeEdit*)(currentNtv->textEdit());
-			disconnect(codeEdit, SIGNAL(text_modified (bool)), this, SLOT(textModified(bool)));
+			
+			SimpleEditor *codeEdit=(SimpleEditor*)(currentNtv->textEdit());
+			disconnect(codeEdit->document(), SIGNAL(modificationChanged (bool)), this, SLOT(textModified(bool)));
 			//disconnect(currentNtv->textEdit()->document(), SIGNAL(modificationChanged (bool)), this, SLOT(textModified(bool)));
 
+			
 			currentNtv->open(path);
+				
 
 			//connect(currentNtv->textEdit()->document(), SIGNAL(modificationChanged (bool)), this, SLOT(textModified(bool)));
-			connect(codeEdit, SIGNAL(text_modified (bool)), this, SLOT(textModified(bool)));
+			connect(codeEdit->document(), SIGNAL(modificationChanged (bool)), this, SLOT(textModified(bool)));
+			
+			setTabText(tabWidget->currentIndex(), path.split("/").last());
 		}
 		catch(...)
 		{
@@ -837,6 +926,29 @@ void Editor::print_callback()
 	}
 }
 
+
+void Editor::clone_callback()
+{
+	QTextDocument *document=currentNtv->textEdit()->document();
+	QString path=currentNtv->path();
+	
+	newEditorTab();
+	
+	currentNtv->textEdit()->setDocument(document);
+	if(!path.isEmpty())
+	{
+		setTabText(tabWidget->currentIndex(), path.split("/").last());
+		currentNtv->setPath(path);
+	}
+}
+
+
+void Editor::toggleBreakPoint_callback()
+{
+	int lineno=currentNtv->textEdit()->textCursor().blockNumber()+1;
+	currentNtv->toggleBreakpoint(lineno);
+}
+
 ////////////////////////////////////////////////////////////////
 
 void Editor::clipboard_double_clicked(const QModelIndex &index)
@@ -887,12 +999,12 @@ int ListModel::position(const QModelIndex &index)
 
 void ListModel::update()
 {
-	printf("[ListModel::update] %d Inicio\n",list.size());
+	//printf("[ListModel::update] %d Inicio\n",list.size());
 	QModelIndex index0=index(0);
 	beginInsertRows(index0, 0, list.size()-1);
-	printf("[ListModel::update] %d Proceso\n",list.size());
+	//printf("[ListModel::update] %d Proceso\n",list.size());
 	endInsertRows();
-	printf("[ListModel::update] %d Fin\n",list.size());
+	//printf("[ListModel::update] %d Fin\n",list.size());
 }
 
 QModelIndex ListModel::position_index(int position)
