@@ -15,6 +15,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+
 #include <QDockWidget>
 
 #include "main.h"
@@ -49,7 +50,7 @@ Main::Main(QObject * parent ):QObject (parent)
 			oc=get_config("octave_path");
 
 
-		QString home=QDir::home().path()+"/.qtoctave/commands.txt";
+		QString home=QDir::home().path()+QDir::separator()+".qtoctave"+QDir::separator()+"commands.txt";
 
 		QString command=
 
@@ -106,10 +107,10 @@ Main::Main(QObject * parent ):QObject (parent)
 	main_window->toolBarDocks->addWidget(window_list);
 	window_list->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Preferred));
 	window_list->show();
-
+	main_window->showMaximized();
 
 	{//Open tools from config
-		QString home=QDir::home().path()+"/.qtoctave/";
+		QString home=QDir::home().path()+QDir::separator()+".qtoctave"+QDir::separator();
 		QString modeWorkArea=get_config("mode_work_area");
 
 		QFile file(home+"last_windows_layout.xml");
@@ -177,10 +178,10 @@ Main::Main(QObject * parent ):QObject (parent)
 	//Build menus from files
 
 	GenerateMenu generate_menu(main_window, operations);
-	generate_menu.setPath( CONFIG_PATH "/menus");
+	generate_menu.setPath( QString(CONFIG_PATH) +QDir::separator()+ "menus");
 	generate_menu.load_menu();
 
-	QString home=QDir::home().path()+"/.qtoctave/";
+	QString home=QDir::home().path()+QString(QDir::separator())+QString(".qtoctave")+QString(QDir::separator());
 
 	generate_menu.setPath( QString(home+"menus") );
 	generate_menu.load_menu();
@@ -213,7 +214,7 @@ Main::Main(QObject * parent ):QObject (parent)
 		connect(oc, SIGNAL(line_ready(QString)), this, SLOT(line_ready(QString)));
 	}
 
-	main_window->showMaximized();
+	//main_window->showMaximized();
 }
 
 void Main::widget_activated(BaseWidget *w)
@@ -247,11 +248,19 @@ void Main::line_ready(QString line)
 
 void Main::help_octave()
 {
-	Help *help=(Help*)createTool(HELP,work_space);
-
-	if(get_config("help_path").isEmpty()) help->setSource( HELP_PATH );
-	else help->setSource(get_config("help_path"));
-	help->show();
+	if(get_config("qtinfo_ok").isEmpty() || get_config("qtinfo_ok")=="false" )
+	{
+		 oc->command_enter("qtinfo");
+	}
+	else
+	{
+		Help *help=(Help*)createTool(HELP,work_space);
+	
+		if(get_config("help_path").isEmpty()) help->setSource( HELP_PATH );
+		else help->setSource(get_config("help_path"));
+		//printf("[Main::help_octave] %s\n", HELP_PATH);
+		help->show();
+	}
 }
 
 void Main::help_qtoctave()
@@ -269,7 +278,7 @@ void Main::help_qtoctave_about()
 	Help *help=(Help*)createTool(HELP,work_space);
 
 	QFileInfo path(QTOCTAVE_HELP_PATH);
-	if(get_config("qtoctave_help_path").isEmpty()) help->setSource( path.absoluteDir().path()+"/about.html");
+	if(get_config("qtoctave_help_path").isEmpty()) help->setSource( path.absoluteDir().path()+QDir::separator()+"about.html");
 	else help->setSource(get_config("qtoctave_help_path"),"about");
 	help->setWindowTitle("QtOctave About");
 	help->show();
@@ -311,11 +320,11 @@ void Main::run_file()
     QString cmd;
     //OctaveConnection *oc = terminal->getOctaveConnection();
 
-    // Cambiar directorio
-    cmd = QString("cd ") + fileInfo.dir().absolutePath();
+    // Change dir
+    cmd = QString("cd \"") + fileInfo.dir().absolutePath() + QString("\"");
     oc->command_enter(cmd);
 
-    // Ejecutar
+    // Execute file
     cmd = fileInfo.baseName();
     oc->command_enter(cmd);
   }
@@ -352,9 +361,8 @@ void Main::editor_callback()
     if(editor.isEmpty()) return;
 
     QString ed(editor);
-    ed+="&";
 
-    system(ed.toAscii().data());
+    QProcess::startDetached (ed);
   }
 }
 
@@ -435,10 +443,13 @@ BaseWidget *Main::createTool(WidgetType type, QWidget *parent)
 		}
 		case EDITOR:
 		{
-			Editor *editor = new Editor(parent);
-			editor->setSession(&session);
-			editor->setOctaveConnection(oc);
-			w=editor;
+			//if( get_config("external_editor") != "true")
+			//{
+				Editor *editor = new Editor(parent);
+				editor->setSession(&session);
+				editor->setOctaveConnection(oc);
+				w=editor;
+			//}
 			break;
 		}
 		case NAVIGATOR:
@@ -551,6 +562,46 @@ void Main::openTools(QXmlStreamReader &xml, QString config_name)
 
 				QString title=attr.value("title").toString();
 				if( !title.isEmpty() ) bw->setWindowTitle(title);
+				
+				if(place!="window") //place=="workspace"
+				{
+					int x=0;
+					if( attr.hasAttribute("xPosition") )
+						x=attr.value("xPosition").toString().toInt();
+					int y=0;
+					if( attr.hasAttribute("yPosition") )
+						y=attr.value("yPosition").toString().toInt();
+					int width=300;
+					if( attr.hasAttribute("width") )
+						width=attr.value("width").toString().toInt();
+					int height=300;
+					if( attr.hasAttribute("height") )
+						height=attr.value("height").toString().toInt();
+					bool maximized=false;
+					if( attr.hasAttribute("maximized") )
+						maximized=(attr.value("maximized").toString()=="true");
+					bool minimized=false;
+					if( attr.hasAttribute("minimized") )
+						minimized=(attr.value("minimized").toString()=="true");
+					if(bw!=NULL)
+					{
+						InitialPosition initPos;
+						initPos.x=x;
+						initPos.y=y;
+						if(width<=0) width=100;
+						if(height<=0) height=100;
+						initPos.width=width;
+						initPos.height=height;
+						initPos.maximized=maximized;
+						initPos.minimized=minimized;
+						initPos.widget=bw->parentWidget();
+						if(initPos.widget!=NULL)
+							initialPositionList.append(initPos);
+						//bw->show();
+						//bw->move(x,y);
+						//bw->resize(width, height);
+					}
+				}
 
 				tools.append(bw);
 
@@ -633,8 +684,24 @@ void Main::openTools(QXmlStreamReader &xml, QString config_name)
 			}
 		}
 	}
+	connect(&timer, SIGNAL(timeout()), this, SLOT(initialPosition_callback()));
+	timer.setSingleShot(true);
+	timer.start(5000);
 }
 
+
+void Main::initialPosition_callback()
+{
+	foreach(InitialPosition i, initialPositionList)
+	{
+		i.widget->move(i.x,i.y);
+		i.widget->resize(i.width, i.height);
+		if(i.maximized) i.widget->showMaximized();
+		if(i.minimized) i.widget->showMinimized();
+	}
+}
+
+
 void Main::openFilesToEdit(QStringList files)
 {
 	if(files.isEmpty()) return;
@@ -668,7 +735,7 @@ int main(int argn, char *argv[])
 	//Se inicializa la configuración
 	get_config("");
 	//Show splash screen
-	QSplashScreen *splash = new QSplashScreen( QPixmap(QString(ICON_PATH) + "/splash.png")/*,  Qt::WindowStaysOnTopHint*/ );
+	QSplashScreen *splash = new QSplashScreen( QPixmap(QString(ICON_PATH) +QDir::separator()+ "splash.png")/*,  Qt::WindowStaysOnTopHint*/ );
 	splash->showMessage ("Starting QtOctave",Qt::AlignBottom|Qt::AlignLeft);
 	splash->show();
 
@@ -686,7 +753,9 @@ int main(int argn, char *argv[])
 	//}
 		
 	if(qtTranslator.load("qt_" + QLocale::system().name(),
-			     "/usr/share/qt4/translations"))
+			     //"/usr/share/qt4/translations"
+			     QLibraryInfo::location(QLibraryInfo::TranslationsPath)
+			     ) )
 	{
 	  a.installTranslator(&qtTranslator);
 	  printf("[main()] Loaded QT Translation file for locale '%s'.\n",
