@@ -16,6 +16,7 @@
  * Boston, MA 02111-1307, USA. 
  */
 
+//#include <QFileSystemModel>
 #include <QDirModel>
 #include <QListView>
 #include <QLineEdit>
@@ -57,7 +58,7 @@ Navigator::Navigator(QWidget *parent) : BaseWidget(parent)
 void Navigator::createActions() 
 {
 	newFolder = new QAction(QIcon(QString(ICON_PATH) + "/new_folder"), tr("&New folder"), this);
-	exit = new QAction(QIcon(QString(ICON_PATH) + "/exit.png"), tr("salir"), this);
+	exit = new QAction(QIcon(QString(ICON_PATH) + "/exit.png"), tr("Exit"), this);
 
 	cut = new QAction(QIcon(QString(ICON_PATH) + "/editcut"), tr("Cu&t"), this);
 	copy = new QAction(QIcon(QString(ICON_PATH) + "/editcopy"), tr("&Copy"), this);
@@ -134,6 +135,13 @@ void Navigator::createLayout()
 	//layout->setMenuBar(menubar);
 	//layout->setStretchFactor(toolbar, 0);
 	//layout->addWidget(toolbar);
+	
+	
+	listmodel = new QFileSystemNewModel();
+	listmodel->setResolveSymlinks(true);
+	listmodel->setFilter(QDir::AllDirs|QDir::AllEntries|QDir::NoDotAndDotDot);
+	listmodel->setNameFilters(QStringList() << "*.m");
+	listmodel->sort(QFileSystemModel::FileNameRole);
 
 	url = new QComboBox(this);
 	url->setEditable(true);
@@ -168,24 +176,8 @@ void Navigator::createLayout()
 	filterBox->addWidget(filter_comboBox);
 	layout->addLayout(filterBox);
 	
-	//treemodel = new QDirModel();
-	//treemodel->setFilter(QDir::Dirs);
 
-	listmodel = new QDirModel();
-	listmodel->setResolveSymlinks(false);
-	listmodel->setFilter(QDir::AllDirs|QDir::AllEntries|QDir::NoDotAndDotDot);
-	listmodel->setNameFilters(QStringList() << "*.m");
-
-	//QSplitter * splitter = new QSplitter(this);
-	//splitter->setMinimumSize(600,300);
-	
-	//QString path = QDir::currentPath();
-
-	//treeview = new QTreeView(this);
-	//treeview->setModel(treemodel);
-	//treeview->setRootIndex(treemodel->index(path));
-
-	QString paths=get_config("navigator_start_path"), path;
+	QString paths=get_config("navigator_start_path"), path = QDir::currentPath();
 	if(!paths.isEmpty())
 	{
 		QStringList values=paths.split("\n");
@@ -198,14 +190,24 @@ void Navigator::createLayout()
 		path = QDir::currentPath();
 		root = listmodel->index(path);
 	}
+	
+	listmodel->setRootPath(QDir::rootPath());
+	
+	printf("[Navigator::createLayout] Building listview\n");
 
-	listview = new DragDropListView(this);
-	listview->setModel(listmodel);
-	listview->setRootIndex(root);
+	listview = new DragDropQTreeView(this);
 	listview->setSelectionMode(QAbstractItemView::ExtendedSelection);
 	listview->setContextMenuPolicy(Qt::CustomContextMenu);
 	listview->setMouseTracking(true);
+	listview->setSortingEnabled(true);
+	listview->setItemsExpandable(false);
+	listview->setRootIsDecorated(false);
+	listview->setModel(listmodel);
+	listview->setRootIndex(root);
 	//listview->setCursor(Qt::OpenHandCursor);
+	
+	//printf("[Navigator::createLayout] Listview builded\n");
+
 
 	url->lineEdit()->setText(path);
 
@@ -215,15 +217,7 @@ void Navigator::createLayout()
 	if (!(listmodel->parent(root)).isValid())
 		up->setEnabled(false);
 
-	//splitter->addWidget(treeview);
-	//splitter->setStretchFactor(splitter->indexOf(treeview), 1);
-	//splitter->addWidget(listview);
-	//splitter->setStretchFactor(splitter->indexOf(listview), 1);
-
-	layout->addWidget(listview, 1);
-
-	//statusbar = new QStatusBar(this);
-	//layout->addWidget(statusbar);
+	layout->addWidget(listview,1);
 }
 
 QString Navigator::getNavigatorCurrentPath()
@@ -263,9 +257,8 @@ void Navigator::setProject(QString name)
 
 void Navigator::createConnections()
 {
-	connect(listview, SIGNAL(clicked(const QModelIndex &)), this, SLOT(expanded(const QModelIndex &)));
+	connect(listview, SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(expanded(const QModelIndex &)));
 	connect(listview, SIGNAL(entered(const QModelIndex &)), this, SLOT(change_cursor_cb(const QModelIndex &)));
-	//connect(listview, SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(drag_start(const QModelIndex &)));
 	connect(back, SIGNAL(triggered(bool)), this, SLOT(goBack(bool)));
 	connect(forward, SIGNAL(triggered(bool)), this, SLOT(goForward(bool)));
 	connect(up, SIGNAL(triggered(bool)), this, SLOT(goUp(bool)));
@@ -333,7 +326,7 @@ void Navigator::expanded(const QModelIndex &index)
 		
 		// Change listview current dir
 		listview->setRootIndex(index);
-		listmodel->refresh(index);
+		//listmodel->refresh(index);
 		
 		if(octave_connection!=NULL)
 		{
@@ -392,7 +385,7 @@ void Navigator::goBack(bool /*checked*/)
 
 		// Change listview current dir
 		listview->setRootIndex(last);
-		listmodel->refresh(last);
+		//listmodel->refresh(last);
 		
 		listview->scrollTo(listmodel->index(rootPath));
 		
@@ -428,7 +421,7 @@ void Navigator::goForward(bool /*checked*/)
 
 		// Change listview current dir
 		listview->setRootIndex(last);
-		listmodel->refresh(last);
+		//listmodel->refresh(last);
 
 		setUpActionState(last);
 
@@ -479,7 +472,7 @@ void Navigator::mkdir()
 		//printf("%s/%s\n",listmodel->filePath(index).toLocal8Bit().data(), dir_name.toLocal8Bit().data() );
 		//listmodel->mkdir(index, dir_name);
 		dir.mkdir(dir_name);
-		listmodel->refresh(index);
+		//listmodel->refresh(index);
 	}
 }
 
@@ -505,10 +498,10 @@ void Navigator::createContextMenu()
 
 /**Returns selected files.
 */
-static QList<QFileInfo> selected_files(QListView *listview, QDirModel *listmodel)
+static QList<QFileInfo> selected_files(QTreeView *listview, QFileSystemNewModel *listmodel)
 {
 	QList<QFileInfo> list;
-	QModelIndexList indexes=listview->selectionModel()->selectedIndexes();
+	QModelIndexList indexes=listview->selectionModel()->selectedRows();
 	for(int i=0; i<indexes.size(); i++)
 	{
 		QModelIndex index=indexes.at(i);
@@ -520,6 +513,7 @@ static QList<QFileInfo> selected_files(QListView *listview, QDirModel *listmodel
 void Navigator::copy_cb()
 {
 	file_list=selected_files(listview, listmodel);
+	file_list_parent_path=listmodel->fileInfo(listview->rootIndex());
 	copy_ok=true;
 	cut_ok=false;
 }
@@ -527,6 +521,7 @@ void Navigator::copy_cb()
 void Navigator::cut_cb()
 {
 	file_list=selected_files(listview, listmodel);
+	file_list_parent_path=listmodel->fileInfo(listview->rootIndex());
 	copy_ok=false;
 	cut_ok=true;
 }
@@ -542,7 +537,7 @@ void Navigator::paste_cb()
 	{
 		QModelIndex index = listview->rootIndex();
 
-		f->copy(file_list, listmodel->filePath(index));
+		f->copy(file_list_parent_path, file_list, listmodel->filePath(index));
 		
 		//copy_ok=false;
 		
@@ -552,7 +547,7 @@ void Navigator::paste_cb()
 	{
 		QModelIndex index = listview->rootIndex();
 
-		f->cut(file_list, listmodel->filePath(index));
+		f->cut(file_list_parent_path, file_list, listmodel->filePath(index));
 		
 		cut_ok=false;
 		
@@ -593,14 +588,14 @@ void Navigator::rename_cb()
 		
 		QFile::rename(fileinfo.absoluteFilePath(), fileinfo.absolutePath()+"/"+name);
 		
-		listmodel->refresh();
+		//listmodel->refresh();
 	}
 }
 
 void Navigator::process_end(QThread *object)
 {
 	object->wait();
-	listmodel->refresh();
+	//listmodel->refresh();
 	delete object;
 }
 
@@ -624,22 +619,40 @@ FileActions::FileActions(QObject *parent):QThread(parent)
 	
 	QVBoxLayout *layout=new QVBoxLayout;
 	
-	label=new QLabel(window);
-	layout->addWidget(label);
-	label->setText(tr("Starting process..."));
-	label->show();
+	progressBar=new QProgressBar(window);
+	layout->addWidget(progressBar);
+	progressBar->setMinimum(0);
+	progressBar->setMaximum(100);
+	progressBar->setValue(0);
+	progressBar->show();
+	
+	textEdit=new QTextEdit(window);
+	layout->addWidget(textEdit);
+	textEdit->setReadOnly(true);
+	textEdit->show();
+	
+	QHBoxLayout *button_layout=new QHBoxLayout;
+	layout->addLayout(button_layout);
+	
+	ok_button=new QPushButton(window);
+	ok_button->setText(tr("Ok"));
+	button_layout->addWidget(ok_button);
+	ok_button->show();
 	
 	cancel_button=new QPushButton(window);
 	cancel_button->setText(tr("Cancel"));
-	layout->addWidget(cancel_button);
+	button_layout->addWidget(cancel_button);
 	cancel_button->show();
 	
 	window->setLayout(layout);
 	
-	connect(this, SIGNAL(file_name(QString)), this, SLOT(set_label_text(QString)) );
 	connect(cancel_button, SIGNAL(clicked()), this, SLOT(stop()) );
+	connect(ok_button, SIGNAL(clicked()), this, SLOT(ok_button_callback()) );
+	connect(this, SIGNAL(process_value(int)), progressBar, SLOT(setValue(int)) );
 	
 	copy_ok=move_ok=remove_ok=stop_ok=false;
+	
+	window->show();
 }
 
 FileActions::~FileActions()
@@ -649,31 +662,39 @@ FileActions::~FileActions()
 
 void FileActions::stop()
 {
+	if(!isRunning()) emit process_end(this);
 	stop_ok=true;
 }
 
-void FileActions::copy(QList<QFileInfo> list, QString path)
+void FileActions::ok_button_callback()
+{
+	start();
+}
+
+void FileActions::copy(QFileInfo parent, QList<QFileInfo> list, QString path)
 {
 	this->list=list;
 	this->path=path;
+	this->parent=parent;
 	
 	copy_ok=true;
 	
 	window->show();
 	
-	start();
+	set_label_text("<p><b>"+tr("These files will be copyed:")+"</b></p>");
 }
 
-void FileActions::cut(QList<QFileInfo> list, QString path)
+void FileActions::cut(QFileInfo parent, QList<QFileInfo> list, QString path)
 {
 	this->list=list;
 	this->path=path;
+	this->parent=parent;
 	
 	move_ok=true;
 	
 	window->show();
 	
-	start();
+	set_label_text("<p><b>"+tr("These files will be cut:")+"</b></p>");
 }
 
 void FileActions::remove(QList<QFileInfo> list)
@@ -683,11 +704,46 @@ void FileActions::remove(QList<QFileInfo> list)
 	
 	window->show();
 	
-	start();
+	set_label_text("<p><b>"+tr("These files will be removed:")+"</b></p>");
+}
+
+QList<QFileInfo> FileActions::find(QList<QFileInfo> files)
+{
+	QList<QFileInfo> list_files;
+	
+	for(int i=0;i<files.size();i++)
+	{
+		list_files.append(find(files[i]));
+	}
+	
+	return list_files;
+}
+
+QList<QFileInfo> FileActions::find(QFileInfo file)
+{
+	QList<QFileInfo> list_files;
+	if(file.isDir())
+	{
+		QDir dir(file.absoluteFilePath());
+		list_files=dir.entryInfoList(QDir::NoDotAndDotDot|QDir::Dirs|QDir::Files);
+		for(int i=0;i<list_files.size();i++)
+		{
+			if(list_files[i].isDir())
+			{
+				QDir dir_aux(list_files[i].absoluteFilePath());
+				list_files.append(dir_aux.entryInfoList(QDir::NoDotAndDotDot|QDir::Dirs|QDir::Files));
+			}
+		}
+	}
+	list_files.append(file);
+	for(int i=0;i<list_files.size();i++)
+		printf("%s\n", list_files[i].absoluteFilePath().toLocal8Bit().data());
+	return list_files;
 }
 
 void FileActions::run()
 {
+	list=find(list);
 	for(int i=0;i<list.size() && !stop_ok;i++)
 	{
 		QFileInfo file=list.at(i);
@@ -695,6 +751,10 @@ void FileActions::run()
 		if(copy_ok) copy(file,path);
 		else if(move_ok) cut(file,path);
 		else if(remove_ok) remove(file);
+		
+		int value=(((double)i)/(double)list.size())*100;
+		
+		emit process_value(value);
 	}
 	
 	emit process_end(this);
@@ -703,55 +763,133 @@ void FileActions::run()
 
 void FileActions::set_label_text(QString text)
 {
-	label->setText("Copy: File "+text);
+	text="<html>"+text;
+	
+	for(int i=0;i<list.size();i++)
+	{
+		text+=list.at(i).absoluteFilePath()+"<br>";
+	}
+	textEdit->setHtml(text+"<html>");
+}
+
+static QString destinationPathToCopy(QFileInfo parent, QFileInfo file, QString path)
+{
+	QDir parent_dir(parent.absoluteFilePath());
+	return path+QDir::separator()+parent_dir.relativeFilePath(file.absoluteFilePath());
 }
 
 void FileActions::copy(QFileInfo file, QString path)
 {
 	QString file_path=file.absoluteFilePath();
-	emit file_name(file_path);
+	QString destination_path=destinationPathToCopy(parent, file, path);
+	
+	printf("[FileActions::copy] Destination %s\n", destination_path.toLocal8Bit().data());
+
+	QFileInfo destination_info(destination_path);
+	if(destination_info.exists()) return;
+	if(file.isDir())
+	{
+		QDir pathDir(path);
+		pathDir.mkpath(destination_path);
+	}
+	else
+	{
+		if(! QFileInfo(destination_info.dir().absolutePath()).exists() )
+		{
+			QDir pathDir(path);
+			pathDir.mkpath(destination_info.dir().absolutePath());
+		}
+		QFile::copy(file_path, destination_path);
+	}
+	
+/*
 	#if defined Q_OS_WIN32
 		system(("copy \""+file_path+"\" \""+path+"\"").toLocal8Bit().data() );
 	#else
-		system(("cp -fRp \""+file_path+"\" \""+path+"\"").toLocal8Bit().data() );
+		system(("cp -fp \""+file_path+"\" \""+path+"\"").toLocal8Bit().data() );
 	#endif
+*/
 }
 
 void FileActions::cut(QFileInfo file, QString path)
 {
-	QString file_path=file.absoluteFilePath();
-	emit file_name(file_path);
+	copy(file, path);
+	remove(file);
+
+/*
 	#if defined Q_OS_WIN32
-		system(("move \""+file_path+"\" \""+path+"\"").toLocal8Bit().data() );
+		copy(file, path);
+		remove(file);
 	#else
-		system(("mv -f \""+file_path+"\" \""+path+"\"").toLocal8Bit().data() );
+		QString file_path=file.absoluteFilePath();
+		QString destination_path=destinationPathToCopy(parent, file, path);
+		
+		printf("[FileActions::cut] Destination %s\n", destination_path.toLocal8Bit().data());
+	
+		QFileInfo destination_info(destination_path);
+		if( destination_info.exists() || !file.exists() ) return;
+		if(file.isDir())
+		{
+			QDir pathDir(path);
+			pathDir.mkpath(destination_path);
+		}
+		else
+		{
+			if(! QFileInfo(destination_info.dir().absolutePath()).exists() )
+			{
+				QDir pathDir(path);
+				pathDir.mkpath(destination_info.dir().absolutePath());
+			}
+			QFile::rename(file_path, destination_path);
+		}
 	#endif
+*/
 }
 
 void FileActions::remove(QFileInfo file)
 {
 	QString file_path=file.absoluteFilePath();
-	emit file_name(file_path);
+	QDir pathDir=file.dir();
+	
+	if(file.isDir())
+	{
+		pathDir.rmpath(file_path);
+	}
+	else
+	{
+		pathDir.remove(file_path);
+	}
+	
+/*
 	#if defined Q_OS_WIN32
 		system(("del \""+file_path+"\"").toLocal8Bit().data() );
 	#else
-		system(("rm -fR \""+file_path+"\"").toLocal8Bit().data() );
+		system(("rm -f \""+file_path+"\"").toLocal8Bit().data() );
 	#endif
+*/
 }
 
-DragDropListView::DragDropListView(QWidget *parent):QListView(parent)
+DragDropQTreeView::DragDropQTreeView(QWidget *parent):QTreeView(parent)
 {
 }
 
-void DragDropListView::mousePressEvent(QMouseEvent *event)
+/*
+void DragDropQTreeView::mousePressEvent(QMouseEvent *event)
 {
 	QModelIndex index=indexAt( event->pos() );
 	if (event->button() == Qt::LeftButton &&  index.isValid() )
 	{
-		QDirModel *listmodel=(QDirModel *)model();
+		QFileSystemNewModel *listmodel=(QFileSystemNewModel *)model();
+		
+		//if( index.column()==-1 )
+		//{
+		//	selectionModel()->select(index, QItemSelectionModel::Toggle);
+		//	return;
+		//}
+		
 		if( listmodel->isDir(index) )
 		{
-			QListView::mousePressEvent(event);
+			QTreeView::mousePressEvent(event);
 			return;
 		}
 		
@@ -766,9 +904,61 @@ void DragDropListView::mousePressEvent(QMouseEvent *event)
 		drag->setPixmap( (QString(ICON_PATH) + "/filenew.png") );
 		//drag->setDragCursor(QCursor(Qt::ClosedHandCursor).pixmap(), Qt::CopyAction);
 	
-		/*Qt::DropAction dropAction = */drag->start();
+		drag->start();
 	}
 }
+*/
+
+void DragDropQTreeView::mousePressEvent(QMouseEvent *event)
+{
+	if (event->button() == Qt::LeftButton)
+	{
+		dragStartPosition = event->pos();
+		//printf("[DragDropQTreeView::mousePressEvent]\n");
+	}
+	QTreeView::mousePressEvent(event);
+}
+
+void DragDropQTreeView::mouseMoveEvent(QMouseEvent *event)
+{
+	QModelIndex index=indexAt( event->pos() );
+	
+	if ( (event->buttons() & Qt::LeftButton) &&  index.isValid() )
+	{
+		//if ((event->pos() - dragStartPosition).manhattanLength() < QApplication::startDragDistance())
+		//	return;
+		QFileSystemNewModel *listmodel=(QFileSystemNewModel *)model();
+		
+		//if( index.column()==-1 )
+		//{
+		//	selectionModel()->select(index, QItemSelectionModel::Toggle);
+		//	return;
+		//}
+		
+		//printf("[DragDropQTreeView::mouseMoveEvent]\n");
+		
+		if( listmodel->isDir(index) )
+		{
+			//QTreeView::mousePressEvent(event);
+			return;
+		}
+		
+		QDrag *drag = new QDrag(this);
+		QMimeData *mimeData = new QMimeData;
+		
+		mimeData->setText(listmodel->filePath(index));
+		
+		//printf("%s\n",listmodel->filePath(index).toLocal8Bit().data());
+		
+		drag->setMimeData(mimeData);
+		drag->setPixmap( (QString(ICON_PATH) + "/filenew.png") );
+		//drag->setDragCursor(QCursor(Qt::ClosedHandCursor).pixmap(), Qt::CopyAction);
+	
+		drag->start();
+	}
+	
+	QTreeView::mouseMoveEvent(event);
+}
 
 BaseWidget *Navigator::copyBaseWidget(QWidget * parent )
 {
