@@ -110,7 +110,7 @@ void OctaveConnection::startOctave(bool quiet)
 	}
 	else
 	{
-		QString command("\""+octave_path+"\"  --eval \"PS1(\'octave:\\#>\');PS2(\'octave:\\#+>\');addpath('"+QString(CONFIG_PATH)+"/scripts_octave/')\"  --persist -H -i "+extra_args);
+		QString command("\""+octave_path+"\"  --eval \"PS1(\'octave:\\#>\');PS2(\'octave:\\#+>\');addpath('"+QDir(QString(CONFIG_PATH)).absolutePath()+QDir::separator()+"scripts_octave"+QDir::separator()+"')\"  --persist --no-history -i "+extra_args);
 		printf("[OctaveConnection::startOctave] Starting octave: %s\n",command.toLocal8Bit().data() );
 		start(command);
 	}
