@@ -149,51 +149,39 @@ void Table::windowActivated(QWidget *w)
 	if(spinbox_dimensions.size()>0) setMatrix(command);
 	
 	command="";
-	
-	command+="if( 0==0 )\n";
-		command+="qtoctave__file_name=tmpnam();\n";
-		//Next line: If matrix doesn't exit, it will build it
-		command+="eval(\""+matrix+";\",\""+matrix+"=[0]\");";
-		if(dimensions.size()==0)
+	//Next line: If matrix doesn't exit, it will build it
+	command+="eval(\""+matrix+";\",\""+matrix+"=[0]\");";
+	command+="_ide_reload_matrix("+matrix+","+QString::number((long)this)+",";
+	if(dimensions.size()==0)
+	{
+			command+="resize("+matrix+"(:,:),size("+matrix+")(1),size("+matrix+")(2) ) ";
+	}
+	else
+	{
+		int x[2]; x[0]=x[1]=-1;
+		QString sub_matrix=matrix+"(";
+		for(int i=0;i<dimensions.size();i++)
 		{
-			command+="qtoctave__aux1=resize("+matrix+"(:,:),size("+matrix+")(1),size("+matrix+")(2) );\n";
-			command+="save(\"-text\", qtoctave__file_name, \"qtoctave__aux1\");\n";
-			//command+="fprintf(stderr,\"~~matrix:"+matrix+" \\\"%s\\\"  "+QString::number((long)this)+"  %d %d \\n\", qtoctave__file_name, rows(qtoctave__aux1),columns(qtoctave__aux1));\n";
-		}
-		else
-		{
-			int x[2]; x[0]=x[1]=-1;
-			QString sub_matrix=matrix+"(";
-			for(int i=0;i<dimensions.size();i++)
+			if(dimensions[i]==":")
 			{
-				if(dimensions[i]==":")
-				{
-					if(x[0]==-1)
-						x[0]=i+1;
-					else
-						x[1]=i+1;
-				}
-				if(i<(dimensions.size()-1))
-					sub_matrix+=dimensions[i]+",";
+				if(x[0]==-1)
+					x[0]=i+1;
 				else
-					sub_matrix+=dimensions[i]+")";
+					x[1]=i+1;
 			}
-			
-			
-			command+="qtoctave__aux1=reshape("+sub_matrix+",size("+matrix+")("+QString::number(x[0])+"),size("+matrix+")("+QString::number(x[1])+") );\n";
-			command+="save(\"-text\", qtoctave__file_name, \"qtoctave__aux1\");\n";
-			//command+="fprintf(stderr,\"~~matrix:"+matrix+" \\\"%s\\\" %d %d "+QString::number((long)this)+"\\n\", qtoctave__file_name, size("+matrix+")("+QString::number(x[0])+"),size("+matrix+")("+QString::number(x[1])+"));\n";
-			
+			if(i<(dimensions.size()-1))
+				sub_matrix+=dimensions[i]+",";
+			else
+				sub_matrix+=dimensions[i]+")";
 		}
-		
-		command+=
-			"fprintf(stderr,\"~~matrix:"+matrix+" \\\"%s\\\" "+QString::number((long)this)+" \", qtoctave__file_name);"
-			"fprintf(stderr, \"%d \", size("+matrix+"));"
-			"fprintf(stderr, \"\\n\");"
-			"\n";
-		command+="clear qtoctave__file_name; clear qtoctave__aux1;\n";
-	command+="endif\n";
+			
+			
+		command+="reshape("+sub_matrix+",size("+matrix+")("+QString::number(x[0])+"),size("+matrix+")("+QString::number(x[1])+") ) ";
+			
+	}
 	
+	command+=", \""+matrix+"\" );";
+
 	//printf("%s",command.toLocal8Bit().data() );
 	
 	octave_connection->command_enter(command,false);
@@ -210,13 +198,13 @@ void Table::reloadCell(int row, int col)
 	if(dimensions.size()==0)
 	{
 		command+= "real("+matrix+"("+QString::number(row+1)+","+QString::number(col+1)+")), "
-		"imag("+matrix+"("+QString::number(row+1)+","+QString::number(col+1)+")));\n";
+		"imag("+matrix+"("+QString::number(row+1)+","+QString::number(col+1)+")));";
 	}
 	else
 	{
 		QString aux=matrix_row_col(QString::number(row+1), QString::number(col+1));
 		
-		command+= "real("+aux+"), imag("+aux+"));\n";
+		command+= "real("+aux+"), imag("+aux+"));";
 	}
 	
 	octave_connection->command_enter(command,false);
@@ -246,8 +234,9 @@ void Table::line_ready(QString line)
 		return;
 	}
 	else if( ! line.startsWith("~~matrix:"+matrix) ) return;
-	//line=line.right(line.length() - (10+matrix.length()) );
-	//printf("line:>%s<\n",line.toLocal8Bit().data());
+	
+	//Read line-event data:
+	//~~matrix:matrix-name "file_name" rows columns
 	
 	QTime time;
 	
@@ -255,29 +244,40 @@ void Table::line_ready(QString line)
 	
 	line=line.trimmed();
 	
-	//Read line-event data:
-	//~~matrix:matrix-name "file_name" rows columns
-	
-	//QRegExp mre("~~matrix:([A-Za-z0-9_]+) \"([^\"]+)\" ([\\d ]+)");
-	
 	int _rows=-1, _columns=-1;
 	QString file_name;
 	QList<int> sizes;
 	
+	//QRegExp mre("~~matrix:([A-Za-z0-9_]+) \"([^\"]+)\" ([\\d ]+)");
+	
 	mre.indexIn ( line ) ;
 	{
 		QStringList list = mre.capturedTexts();
 		//for(int i=0;i<list.size();i++)
 		//	printf("Texto(%d): %s\n", i, list.at(i).toLocal8Bit().data());
 		QStringList numbers=list.at(3).trimmed().split(" ", QString::SkipEmptyParts);
+		
+		long thisValue=numbers.at(0).toLong();
+		if( ((long)this)!=thisValue )
+                {
+		   qDebug("PROBLEM: value mismatch; %ld != %ld\n", (long)this, thisValue);
+		   return;
+                }
+                //printf("[Table::line_ready] this id=%ld table id=%ld\n", (long)this, thisValue);
+
+                numbers.removeFirst();
+		
 		for(int i=0;i<numbers.size();i++)
 		{
 			sizes.append(numbers.at(i).toInt());
+			printf("[Table::line_ready] sizes=%d\n", numbers.at(i).toInt());
 		}
-		if( ((long)this)!=sizes.at(0) ) return;
+		//if( ((long)this)!=sizes.at(0) ) return;
 		
 		file_name=list.at(2);
-		sizes.removeFirst();
+
+		//Already removed in numbers.removeFirst()
+		//sizes.removeFirst();
 		
 		int x[2]; x[0]=x[1]=-1;
 		for(int i=0;i<dimensions.size();i++)
@@ -382,6 +382,8 @@ void Table::line_ready(QString line)
 				col++;
 				if(ch=='\n') {row++;col=0;}
 				data_available_ok=false;
+				real.clear();
+				imag.clear();
 			}
 		}
 		
@@ -391,7 +393,8 @@ void Table::line_ready(QString line)
 		
 		//connect(model,SIGNAL(cellChanged( int, int, QString)),this,SLOT(cellChanged( int, int, QString)));
 		
-		printf("Data loaded in %dms\n", time.elapsed() );
+		printf("[Table::line_ready] Data loaded in %dms\n", time.elapsed() );
+		fflush(stdout);
 		
 		model->update();
 	}
