@@ -8,7 +8,7 @@
 #define __CONFIG_H__
 
 #ifndef DEFAULT_REPOSITORY_FILE
-#define DEFAULT_REPOSITORY_FILE "https://forja.rediris.es/svn/csl-qtoctave/trunk/qtoctave_pkg/octave-forge.list"
+#define DEFAULT_REPOSITORY_FILE "https://forja.rediris.es/svn/csl-qtoctave/trunk/qtoctave_pkg/octave-forge.xml"
 #endif
 
 #ifndef USER_CONFIG_FILE
@@ -20,7 +20,7 @@
 #endif
 
 #ifndef CONNECTION_TIMEOUT
-#define CONNECTION_TIMEOUT 10000
+#define CONNECTION_TIMEOUT 20000
 #endif
 
 #endif
