@@ -15,7 +15,8 @@ class PkgManager: public QMainWindow, public Ui::MainWindow
 {
   Q_OBJECT
  private:
-  QMap<QString, QList<OctaveBind::Package> > packageTree;
+  //QMap<QString, QList<OctaveBind::Package> > packageTree;
+  QList<OctaveBind::Package> packList;
   QString        currentPackage;
   DownloadDialog download;
   QList<OctaveBind::Package> installList, removeList;
@@ -34,7 +35,14 @@ class PkgManager: public QMainWindow, public Ui::MainWindow
    * name:     The name of the group (i.e. 'Main repository')
    * children: The list of packages
    */
-  void addGroup(const QString &name, const QList<OctaveBind::Package> &children);
+  void addGroup(const QString &name/*, const QList<OctaveBind::Package> &children*/);
+
+/* Adds a list of packages to the repository
+   * name:     The name of the group (i.e. 'Main repository')
+   * children: The list of packages
+   */
+  void addPackageList(const QList<OctaveBind::Package> &children);
+
 
   /* Clears the tree
    */
